---
title: <span class="badge object-type-scalar"></span> KiloWattHour
---
# <span class="badge object-type-scalar"></span> KiloWattHour

Energy: Kilowatt-hour (kWh)

## Definition

```python
# Energy: Kilowatt-hour (kWh)
KiloWattHour: typing.Literal["kwatth"] = "kwatth"
```
